@@ -77,7 +77,9 @@ def project_graphql_query(fields):
 
 def projects_graphql_query(fields):
     query = GraphQlQuery("ProjectsQuery")
+    project_name_var = query.add_variable("projectName", "String!")
     projects_field = query.add_field_with_edges("projects")
+    projects_field.set_filter("name", project_name_var)
 
     nested_fields = fields_to_dict(fields)
 
@@ -119,30 +121,6 @@ def product_types_query(fields):
     return query
 
 
-def project_product_types_query(fields):
-    query = GraphQlQuery("ProjectProductTypes")
-    project_query = query.add_field("project")
-    project_name_var = query.add_variable("projectName", "String!")
-    project_query.set_filter("name", project_name_var)
-    product_types_field = project_query.add_field("productTypes")
-    nested_fields = fields_to_dict(fields)
-
-    query_queue = collections.deque()
-    for key, value in nested_fields.items():
-        query_queue.append((key, value, product_types_field))
-
-    while query_queue:
-        item = query_queue.popleft()
-        key, value, parent = item
-        field = parent.add_field(key)
-        if value is FIELD_VALUE:
-            continue
-
-        for k, v in value.items():
-            query_queue.append((k, v, field))
-    return query
-
-
 def folders_graphql_query(fields):
     query = GraphQlQuery("FoldersQuery")
     project_name_var = query.add_variable("projectName", "String!")
@@ -300,8 +278,8 @@ def products_graphql_query(fields):
     product_types_var = query.add_variable("productTypes", "[String!]")
     product_name_regex_var = query.add_variable("productNameRegex", "String!")
     product_path_regex_var = query.add_variable("productPathRegex", "String!")
-    statuses_var = query.add_variable("productStatuses.", "[String!]")
-    tags_var = query.add_variable("productTags.", "[String!]")
+    statuses_var = query.add_variable("productStatuses", "[String!]")
+    tags_var = query.add_variable("productTags", "[String!]")
 
     project_field = query.add_field("project")
     project_field.set_filter("name", project_name_var)
@@ -341,6 +319,7 @@ def versions_graphql_query(fields):
     project_name_var = query.add_variable("projectName", "String!")
     product_ids_var = query.add_variable("productIds", "[String!]")
     version_ids_var = query.add_variable("versionIds", "[String!]")
+    task_ids_var = query.add_variable("taskIds", "[String!]")
     versions_var = query.add_variable("versions", "[Int!]")
     hero_only_var = query.add_variable("heroOnly", "Boolean")
     latest_only_var = query.add_variable("latestOnly", "Boolean")
@@ -357,6 +336,7 @@ def versions_graphql_query(fields):
     versions_field.set_filter("ids", version_ids_var)
     versions_field.set_filter("productIds", product_ids_var)
     versions_field.set_filter("versions", versions_var)
+    versions_field.set_filter("taskIds", task_ids_var)
     versions_field.set_filter("heroOnly", hero_only_var)
     versions_field.set_filter("latestOnly", latest_only_var)
     versions_field.set_filter("heroOrLatestOnly", hero_or_latest_only_var)
@@ -617,10 +597,12 @@ def events_graphql_query(fields, order, use_states=False):
 def users_graphql_query(fields):
     query = GraphQlQuery("Users")
     names_var = query.add_variable("userNames", "[String!]")
+    emails_var = query.add_variable("emails", "[String!]")
     project_name_var = query.add_variable("projectName", "String!")
 
     users_field = query.add_field_with_edges("users")
     users_field.set_filter("names", names_var)
+    users_field.set_filter("emails", emails_var)
     users_field.set_filter("projectName", project_name_var)
 
     nested_fields = fields_to_dict(set(fields))
@@ -683,3 +665,33 @@ def activities_graphql_query(fields, order):
             query_queue.append((k, v, field))
 
     return query
+
+
+def entity_lists_graphql_query(fields):
+    query = GraphQlQuery("EntityLists")
+    project_name_var = query.add_variable("projectName", "String!")
+    entity_list_ids = query.add_variable("listIds", "[String!]")
+
+    project_field = query.add_field("project")
+    project_field.set_filter("name", project_name_var)
+
+    entity_lists_field = project_field.add_field_with_edges("entityLists")
+    entity_lists_field.set_filter("ids", entity_list_ids)
+
+    nested_fields = fields_to_dict(set(fields))
+
+    query_queue = collections.deque()
+    for key, value in nested_fields.items():
+        query_queue.append((key, value, entity_lists_field))
+
+    while query_queue:
+        item = query_queue.popleft()
+        key, value, parent = item
+        field = parent.add_field(key)
+        if value is FIELD_VALUE:
+            continue
+
+        for k, v in value.items():
+            query_queue.append((k, v, field))
+
+    return query
